==> haskell-logging-facade-0.3.0-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-GBsRkky8Dd228KNlwvVK4
key: logging-facade-0.3.0-GBsRkky8Dd228KNlwvVK4
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: b8d69c4ba728105da3978ec41f7afee8
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.6.1/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-GBsRkky8Dd228KNlwvVK4
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.0-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: logging-facade
version: 0.3.0
id: logging-facade-0.3.0-KHQeML57OlL4frWB9RXbyL
key: logging-facade-0.3.0-KHQeML57OlL4frWB9RXbyL
license: MIT
copyright: (c) 2014-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/logging-facade#readme
synopsis: Simple logging abstraction that allows multiple back-ends
description:
    Simple logging abstraction that allows multiple back-ends
category: System
abi: 12329cd878aa543fbf2c54f33db6bc0f
exposed: True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types
hidden-modules: Paths_logging_facade
import-dirs: /usr/lib/ghc-8.6.2/site-local/logging-facade-0.3.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/logging-facade-0.3.0
hs-libraries: HSlogging-facade-0.3.0-KHQeML57OlL4frWB9RXbyL
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock
haddock-html: /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
